# Generated by Django 4.2.7 on 2023-10-31 23:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):
    dependencies = [
        ("wagtailimages", "0025_alter_image_file_alter_rendition_file"),
        ("cjkcms", "0016_layoutsettings_breadcrumb_icon_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="layoutsettings",
            name="default_seo_image",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                related_name="default_seo_image",
                to="wagtailimages.image",
                verbose_name="Default SEO Image",
            ),
        ),
    ]



import unittest
from unittest.mock import Mock

from cjkcms.draftail import (
    register_block_feature,
    register_inline_styling,
    NewWindowExternalLinkHandler,
)
from cjkcms.draftail.draftail_extensions import create_control_dict


class TestCreateControlDict(unittest.TestCase):
    def test_create_control_dict_basic(self):
        control = create_control_dict("bold", "Bold")
        self.assertEqual(
            control, {"type": "bold", "description": "Bold", "label": "Bold"}
        )

    def test_create_control_dict_with_optional_args(self):
        control = create_control_dict(
            "italic", "Italic", label="Italic Style", editor_style="font-style:italic;"
        )
        self.assertEqual(
            control,
            {
                "type": "italic",
                "description": "Italic",
                "label": "Italic Style",
                "style": "font-style:italic;",
            },
        )


class TestRegisterFeatures(unittest.TestCase):
    def setUp(self):
        self.mock_features = Mock()

    def test_register_inline_styling(self):
        register_inline_styling(
            self.mock_features, "custom-style", "Custom Style", "CUSTOM", tag="span"
        )
        self.mock_features.register_editor_plugin.assert_called()
        self.mock_features.register_converter_rule.assert_called()

    def test_register_block_feature(self):
        register_block_feature(
            self.mock_features,
            "custom-block",
            "Custom Block",
            "CUSTOM-BLOCK",
            "custom-class",
        )
        self.mock_features.register_editor_plugin.assert_called()
        self.mock_features.register_converter_rule.assert_called()


class TestNewWindowExternalLinkHandler(unittest.TestCase):
    def test_expand_db_attributes_with_blank(self):
        result = NewWindowExternalLinkHandler.expand_db_attributes(
            {"href": "http://example.com?_blank"}
        )
        self.assertIn('target="_blank"', result)
        self.assertIn('rel="noopener noreferrer"', result)

    def test_expand_db_attributes_without_blank(self):
        result = NewWindowExternalLinkHandler.expand_db_attributes(
            {"href": "http://example.com"}
        )
        self.assertNotIn('target="_blank"', result)
        self.assertNotIn('rel="noopener noreferrer"', result)



# Generated by Django 5.0.2 on 2024-02-18 13:58

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cjkcms', '0017_layoutsettings_default_seo_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='layoutsettings',
            name='search_format',
            field=models.CharField(blank=True, choices=[], default='', max_length=50, verbose_name='Search format'),
        ),
    ]



from django.utils.html import strip_tags
from django.utils.safestring import mark_safe
from datetime import datetime, timezone


def get_richtext_preview(content, max_length=200):
    """Returns a shortened version of a richtext field's content,
    with HTML tags stripped, and trimmed to max_length.
    >>> get_richtext_preview('<h1><div>Hello </div>world</h1>')
    'Hello world'
    >>> get_richtext_preview('Hi worl\x64')
    'Hi world'"""
    # strip tags
    c = strip_tags(content)
    # truncate and add ellipses
    preview = f"{c[:max_length]}..." if len(c) > 200 else c
    return mark_safe(preview)


def can_show_block(
    context,
    item_visibility: str,
    groups: str,
    visible_from: datetime | None,
    visible_to: datetime | None,
) -> bool:
    """
    Block/item visibility conditional on selection in cms_settings.AUTH_VISIBILITY_CHOICES,
    as well as visible_from and visible_to datetimes.
    """

    if item_visibility == "hidden":
        return False

    now = datetime.now(timezone.utc)

    if visible_from and visible_from > now:
        return False

    if visible_to and visible_to < now:
        return False

    if item_visibility == "all":
        return True

    # if context is None or "request" not in context:
    #     is_auth = False
    # else:
    try:
        is_auth = context["request"].user.is_authenticated
    except (KeyError, TypeError):
        is_auth = False

    if not is_auth:
        return item_visibility == "non-auth-only"

    # here is_auth is True
    if item_visibility == "auth-only":
        return True

    # group include or exclude
    if item_visibility not in ["include-groups", "exclude-groups"]:
        return False

    groups_list = [word.strip() for word in groups.split(",")]
    user_in_group = context["request"].user.groups.filter(name__in=groups_list).exists()

    return (item_visibility == "include-groups" and user_in_group) or (
        item_visibility == "exclude-groups" and not user_in_group
    )



# Generated by Django 4.2.3 on 2023-08-04 20:23

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0012_remove_analyticssettings_ga_tracking_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialmediasettings",
            name="location",
            field=models.CharField(
                blank=True,
                choices=[
                    ("left", "left"),
                    ("right", "right"),
                    ("menu", "menu"),
                    ("none", "none"),
                ],
                default="none",
                max_length=50,
                verbose_name="Location of social media block",
            ),
        ),
    ]



from cjkcms.models import (
    CjkcmsArticlePage,
    CjkcmsArticleIndexPage,
    CjkcmsWebPage,
)


class ProjectArticlePage(CjkcmsArticlePage):
    template = "cjkcms/pages/article_page.html"
    search_template = "cjkcms/pages/article_page.search.html"


class ProjectArticleIndexPage(CjkcmsArticleIndexPage):
    template = "cjkcms/pages/article_index_page.html"


class ProjectWebPage(CjkcmsWebPage):
    # use cjkcms template by default
    template = "cjkcms/pages/web_page.html"
